Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckModFileExists ¶ added in v2.2.2
CheckModFileExists makes sure that a go.mod file exists in the supplied directory
func LocateFacilityConfig ¶
LocateFacilityConfig determines where on your filesystem you have checked out Granitic. This is used when code needs access to the configuration for Granitic's built-in facility components which is stored under resource/facility-config
func SerialiseBuiltinConfig ¶
SerialiseBuiltinConfig takes the configuration files for Granitic's internal components (facilities) found in resource/facility-config and serialises them into a single string that will be embedded into your application's executable.
Types ¶
type Binder ¶
type Binder struct {
Loader DefinitionLoader
ToolName string
Log logging.Logger
// contains filtered or unexported fields
}
Binder translates the components defined in component definition files into Go source code.
type DefinitionLoader ¶
type DefinitionLoader interface {
LoadAndMerge(files []string, log logging.Logger) (map[string]interface{}, error)
WriteMerged(data map[string]interface{}, path string, log logging.Logger) error
}
A DefinitionLoader handles the loading of component definition files from a sequence of file paths and can write a merged version of those files to a location on a filesystem.
type Settings ¶
type Settings struct {
CompDefLocation *string
BindingsFile *string
MergedDebugFile *string
LogLevelLabel *string
LogLevel logging.LogLevel
}
Settings contains output/input file locations and other variables for controlling the behaviour of this tool
func SettingsFromArgs ¶
SettingsFromArgs uses CLI parameters to populate a Settings object